@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_VERSION_H
-#define DIGIKAM_VERSION_H
+#pragma once
 
 // Qt includes
 
@@ -27,8 +26,8 @@
 namespace Digikam
 {
 
-static const char digikam_version_short[]  = "8.3.0";
-static const char digikam_version[]        = "8.3.0";
+static const char digikam_version_short[]  = "8.4.0";
+static const char digikam_version[]        = "8.4.0";
 static const char digikam_version_suffix[] = "";
 static const char digikam_build_type[]     = "";
 
@@ -54,5 +53,3 @@ DIGIKAM_EXPORT const QDateTime digiKamBuildDate();
 DIGIKAM_EXPORT int digiKamMakeIntegerVersion(int major, int minor, int patch);
 
 } // namespace Digikam
-
-#endif // DIGIKAM_VERSION_H
